# -*- rpm-spec -*-

# This macro is used for the continuous automated builds. It just
# allows an extra fragment based on the timestamp to be appended
# to the release. This distinguishes automated builds, from formal
# Fedora RPM builds
%define _extra_release %{?dist:%{dist}}%{!?dist:%{?extra_release:%{extra_release}}}

Name: virt-manager
Version: 0.4.0
Release: 3%{_extra_release}.1
Summary: Virtual Machine Manager

Group: Applications/Emulators
License: GPL
URL: http://virt-manager.et.redhat.com/
Source0: http://virt-manager.et.redhat.com/download/sources/%{name}/%{name}-%{version}.tar.gz
Source1: %{name}.pam
Source2: %{name}.console
Source3: %{name}-%{version}-po-2007-05-09.tar.gz
Patch1: %{name}-%{version}-file-dialog-fix.patch
Patch2: %{name}-%{version}-toolbar-state.patch
Patch3: %{name}-%{version}-device-remove.patch
Patch4: %{name}-%{version}-default-dirs.patch
Patch5: %{name}-%{version}-default-image.patch
Patch6: %{name}-%{version}-release-deleted-domain.patch
Patch7: %{name}-%{version}-dbus-interface.patch
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

# These two are just the oldest version tested
Requires: pygtk2 >= 1.99.12-6
Requires: gnome-python2-gconf >= 1.99.11-7
# Absolutely require this version or newer
Requires: libvirt-python >= 0.2.1-1.el5
# Definitely does not work with earlier due to python API changes
Requires: dbus-python >= 0.61
# Might work with earlier, but this is what we've tested
Requires: gnome-keyring >= 0.4.9
# Minimum we've tested with
# Although if you don't have this, comment it out and the app
# will work just fine - keyring functionality will simply be
# disabled
Requires: gnome-python2-gnomekeyring >= 2.15.4
# Minimum we've tested with
Requires: libxml2-python >= 2.6.23
# Required to install Xen guests
Requires: python-virtinst >= 0.103.0
# Required for loading the glade UI
Requires: pygtk2-libglade
# Required for our graphics which are currently SVG format
Requires: librsvg2
# Earlier vte had broken python binding module
Requires: vte >= 0.12.2
# For the consolehelper PAM stuff
Requires: usermode
# For online help
Requires: scrollkeeper

ExclusiveArch: %{ix86} x86_64 ia64

BuildRequires: pygtk2-devel
BuildRequires: gtk2-devel
BuildRequires: python-devel
BuildRequires: gettext
BuildRequires: scrollkeeper
Requires(pre): GConf2
Requires(post): GConf2
Requires(preun): GConf2
Requires(post): desktop-file-utils
Requires(postun): desktop-file-utils

%description
Virtual Machine Manager provides a graphical tool for administering
virtual machines such as Xen. It uses libvirt as the backend management
API.

%prep
%setup -q -a 3
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1

%build
%configure
make %{?_smp_mflags}


%install
rm -rf $RPM_BUILD_ROOT
make install  DESTDIR=$RPM_BUILD_ROOT
rm -f $RPM_BUILD_ROOT%{_libdir}/%{name}/sparkline.a
rm -f $RPM_BUILD_ROOT%{_libdir}/%{name}/sparkline.la

# Adjust for console-helper magic
mkdir -p $RPM_BUILD_ROOT%{_sbindir}
mv $RPM_BUILD_ROOT%{_bindir}/%{name} $RPM_BUILD_ROOT%{_sbindir}/%{name}
ln -s %{_bindir}/consolehelper $RPM_BUILD_ROOT%{_bindir}/%{name}
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/pam.d
cp %{SOURCE1} $RPM_BUILD_ROOT%{_sysconfdir}/pam.d/%{name}
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/security/console.apps
cp %{SOURCE2} $RPM_BUILD_ROOT%{_sysconfdir}/security/console.apps/%{name}

%find_lang %{name}

%clean
rm -rf $RPM_BUILD_ROOT

%pre
if [ "$1" -gt 1 ]; then
    export GCONF_CONFIG_SOURCE=`gconftool-2 --get-default-source`
    gconftool-2 --makefile-uninstall-rule \
      %{_sysconfdir}/gconf/schemas/%{name}.schemas > /dev/null || :
fi

%post
export GCONF_CONFIG_SOURCE=`gconftool-2 --get-default-source`
gconftool-2 --makefile-install-rule \
  %{_sysconfdir}/gconf/schemas/%{name}.schemas > /dev/null || :

update-desktop-database %{_datadir}/applications

if which scrollkeeper-update>/dev/null 2>&1; then scrollkeeper-update -q -o %{_datadir}/omf/%{name}; fi

%postun
update-desktop-database %{_datadir}/applications

if which scrollkeeper-update>/dev/null 2>&1; then scrollkeeper-update -q; fi

%preun
if [ "$1" -eq 0 ]; then
    export GCONF_CONFIG_SOURCE=`gconftool-2 --get-default-source`
    gconftool-2 --makefile-uninstall-rule \
      %{_sysconfdir}/gconf/schemas/%{name}.schemas > /dev/null || :
fi

%files -f %{name}.lang
%defattr(-,root,root,-)
%doc README COPYING COPYING-DOCS AUTHORS ChangeLog NEWS
%{_sysconfdir}/gconf/schemas/%{name}.schemas
%{_sysconfdir}/pam.d/%{name}
%{_sysconfdir}/security/console.apps/%{name}
%{_bindir}/%{name}
%{_sbindir}/%{name}
%{_libexecdir}/%{name}-launch
%dir %{_libdir}/%{name}/
%{_libdir}/%{name}/*

%dir %{_datadir}/%{name}/
%{_datadir}/%{name}/*.glade
%{_datadir}/%{name}/*.py
%{_datadir}/%{name}/*.pyc
%{_datadir}/%{name}/*.pyo

%dir %{_datadir}/%{name}/pixmaps/
%{_datadir}/%{name}/pixmaps/*.png
%{_datadir}/%{name}/pixmaps/*.svg

%dir %{_datadir}/%{name}/virtManager/
%{_datadir}/%{name}/virtManager/*.py
%{_datadir}/%{name}/virtManager/*.pyc
%{_datadir}/%{name}/virtManager/*.pyo

%dir %{_datadir}/%{name}/vncViewer/
%{_datadir}/%{name}/vncViewer/*.py
%{_datadir}/%{name}/vncViewer/*.pyc
%{_datadir}/%{name}/vncViewer/*.pyo

%{_datadir}/omf/%{name}/
%{_datadir}/gnome/help/%{name}/

%{_datadir}/applications/%{name}.desktop
%{_datadir}/dbus-1/services/%{name}.service

%changelog
* Tue Mar 11 2008 Daniel P. Berrange <berrange@redhat.com> - 0.4.0-3.el5_1.1
- Fix use of DBus interface (rhbz #436755)

* Tue Jul 24 2007 Hugh O. Brock <hbrock@redhat.com> - 0.4.0-3.el5
- Aggressively free libvirt domain object after it has been deleted. Workaround
  for python's unreliable garbage collection. (rhbz #249094)

* Thu Jul 12 2007 Daniel P. Berrange <berrange@redhat.com> - 0.4.0-2.el5
- Suggest a disk name for file backed VMs (rhbz #216704)

* Thu Jun 14 2007 Daniel P. Berrange <berrange@redhat.com> - 0.4.0-1.el5
- Updated to 0.4.0 release (rhbz #243464, 217596, 215020, 214724)

* Tue Feb 27 2007 Daniel P. Berrange <berrange@redhat.com> - 0.2.6-9.el5
- Implement alternate approach to processing ungrab key sequence

* Fri Feb 23 2007 Daniel P. Berrange <berrange@redhat.com> - 0.2.6-8.el5
- Grab cursor & hide local mouse in console window

* Tue Jan  9 2007 Daniel P. Berrange <berrange@redhat.com> - 0.2.6-7.el5
- Explicitly drop the libvirt virDomainPtr object when a guest shuts down
  to avoid hanging onto objects in libvirt cache (bz 220036)

* Mon Dec 18 2006 Daniel P. Berrange <berrange@redhat.com> - 0.2.6-6.el5
- Imported latest translations from Fedora i18n repository (bz 203783)

* Sun Dec 17 2006 Hugh Brock <hbrock@redhat.com> - 0.2.6-5.el5
- Add selector for sparse or non-sparse file, defaulting to non-sparse. 
  Add appropriate warnings and progress-bar text. (bz 218996)

* Wed Dec 13 2006 Daniel Berrange <berrange@localhost.localdomain> - 0.2.6-4.el5
- Disable memory ballooning & CPU hotplug for HVM guests (bz 214432)

* Tue Dec 12 2006 Hugh Brock <hbrock@redhat.com> - 0.2.6-3.el5
- Updated memory-setting UI to include a hard upper limit for physical 
  host RAM
- Added documentation on the page warning that setting virtual host RAM
  too high can exhaust the memory of the machine

* Mon Dec 11 2006 Daniel Berrange <berrange@localhost.localdomain> - 0.2.6-2.el5
- Imported latest translations from Fedora i18n repository (bz 203783)

* Thu Dec  7 2006 Daniel Berrange <berrange@redhat.com> - 0.2.6-1.el5
- Updated to match 0.2.6-2 release from FC6 tree (bz 218537)
- Handle errors when hostname resolution fails to avoid app exiting
- Make (most) scrollbar policies automatic
- Set busy cursor while creating new VMs
- Preference for controlling keygrab policy
- Added activation of URLs for about dialog
- Improved error reporting when connecting to HV
- Don't skip para/full virt wizard step - instead gray out full
  virt option & tell user why
- Change 'physical' to 'logical' when refering to host CPUs
- Include hostname in titlebar
- Disable wizard sensitivity while creating VM

* Tue Nov 28 2006 Hugh O. Brock <hbrock@redhat.com> - 0.2.5-3.el5
- Add automatic console popups on launching a VM, plus a few console fixes (bz 211385)

* Tue Nov 21 2006 Hugh O. Brock <hbrock@redhat.com> - 0.2.5-2.el5
- Add command-line interface for virt-manager (bz 211553)
- Make virt-manager exit gtk.main when windows opened from the 
  command-line interface are closed (bz 213782)

* Thu Oct 19 2006 Daniel P. Berrange <berrange@redhat.com> - 0.2.5-1.el5
- Switch to use python-virtinst instead of python-xeninst due to 
  renaming of original package
- Disable keyboard accelerators when grabbing mouse to avoid things like
  Ctrl-W closing the local window, instead of remote window bz 210364
- Fix host memory reporting bz 211281
- Remove duplicate application menu entry bz 211230
- Fix duplicated mnemonics (bz 211231)
- Use a drop down list to remember past URLs (bz 211233)
- Remove unused help button from preferences dialog (bz 211232)
- Fix exception when no VNC graphics is defined
- Force immediate refresh of VMs after creating a new one
- Improve error reporting if run on a kernel without Xen (bz 211229)
- More fixes to avoid stuck modifier keys on focus-out (bz 211461)

* Sat Oct  7 2006 Daniel P. Berrange <berrange@redhat.com> 0.2.3-3.el5
- Use blktap based driver for file backed disks by default

* Fri Sep 29 2006 Daniel P. Berrange <berrange@redhat.com> 0.2.3-2.fc6
- Fix segv in sparkline code when no data points are defined (bz  208185)
- Clamp CPU utilization between 0 & 100% just in case (bz 208185)

* Tue Sep 26 2006 Daniel Berrange <berrange@redhat.com> - 0.2.3-1.fc6
- Require xeninst >= 0.93.0 to fix block backed devices
- Skip para/fully-virt step when going back in wizard if not HVM host (bz 207409)
- Fix handling of modifier keys in VNC console so Alt key doesn't get stuck (bz 207949)
- Allow sticky modifier keys by pressing same key 3 times in row (enables Ctrl-Alt-F1
  by doing Ctrl Ctrl Ctrl  Alt-F1)
- Improved error handling during guest creation
- Log errors with python logging, instead of to stdout
- Remove unused buttons from main domain list window
- Switch out of full screen & release key grab when closing console
- Trim sparkline CPU history graph to 40 samples max
- Constraint VCPU adjuster to only allow upto guest's max VCPU count
- Show guest's max & current VCPU count in details page
- Fix rounding of disk sizes to avoid a 1.9 GB disk being rounded down to 1 GB
- Use raw block device path to CDROM not mount point for HVM guest (bz 206965)
- Fix visibility of file size spin box (bz 206186 part 2)
- Check for GTK failing to open X11 display (bz 205938)

* Fri Sep 15 2006 Daniel Berrange <berrange@redhat.com> - 0.2.2-1.fc6
- Fix event handling in create VM wizard (bz 206660 & 206186)
- Fix close button in about dialog (bz 205943)
- Refresh .pot files
- Turn on VNC scrollbars fulltime to avoid GTK window sizing issue
  which consistently resize too small.

* Mon Sep 11 2006 Daniel Berrange <berrange@redhat.com> - 0.2.1-3.fc6
- Added requires on pygtk2-libglade & librsvg2 (bz 205941 & 205942)
- Re-arrange to use console-helper to launch app
- Added 'dist' component to release number

* Wed Sep  6 2006 Jeremy Katz <katzj@redhat.com> - 0.2.1-2
- don't ghost pyo files (#205448)

* Mon Sep  4 2006 Daniel Berrange <berrange@redhat.com> - 0.2.1-1
- Updated to 0.2.1 tar.gz
- Added rules to install/uninstall gconf schemas in preun,post,pre
  scriptlets
- Updated URL for source to reflect new upstream download URL

* Thu Aug 24 2006 Jeremy Katz <katzj@redhat.com> - 0.2.0-3
- BR gettext

* Thu Aug 24 2006 Jeremy Katz <katzj@redhat.com> - 0.2.0-2
- only build on arches with virt

* Tue Aug 22 2006 Daniel Berrange <berrange@redhat.com> - 0.2.0-1
- Added wizard for creating virtual machines
- Added embedded serial console
- Added ability to take screenshots

* Mon Jul 24 2006 Daniel Berrange <berrange@redhat.com> - 0.1.5-2
- Prefix *.pyo files with 'ghost' macro
- Use fully qualified URL in Source  tag

* Thu Jul 20 2006 Daniel Berrange <berrange@redhat.com> - 0.1.5-1
- Update to new 0.1.5 release snapshot

* Thu Jul 20 2006 Daniel Berrange <berrange@redhat.com> - 0.1.4-1
- Update to new 0.1.4 release snapshot

* Mon Jul 17 2006 Daniel Berrange <berrange@redhat.com> - 0.1.3-1
- Fix License tag
- Updated for new release

* Wed Jun 28 2006 Daniel Berrange <berrange@redhat.com> - 0.1.2-3
- Added missing copyright headers on all .py files

* Wed Jun 28 2006 Daniel Berrange <berrange@redhat.com> - 0.1.2-2
- Added python-devel to BuildRequires

* Wed Jun 28 2006 Daniel Berrange <berrange@redhat.com> - 0.1.2-1
- Change URL to public location

* Fri Jun 16 2006 Daniel Berrange <berrange@redhat.com> - 0.1.0-1
- Added initial support for using VNC console

* Thu Apr 20 2006 Daniel Berrange <berrange@redhat.com> - 0.0.2-1
- Added DBus remote control service

* Wed Mar 29 2006 Daniel Berrange <berrange@redhat.com> - 0.0.1-1
- Initial RPM build
